@@ -2,7 +2,6 @@
 from unittest import TestCase
 
 from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.ovh import Provider
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
@@ -10,7 +9,6 @@ from lexicon.providers.ovh import Provider
 # pass, by inheritance from integration_tests.IntegrationTests
 class OvhProviderTests(TestCase, IntegrationTests):
     """TestCase for OVH"""
-    Provider = Provider
     provider_name = 'ovh'
     domain = 'pacalis.net'
 
